import { useCallback, useMemo } from 'react';
import { EMPTY } from 'rxjs';
import { useObservableState } from '@equinor/fusion-observable/react';
import { findFeature } from '@equinor/fusion-framework-module-feature-flag/selectors';
/**
 * Custom hook that retrieves a feature flag from a feature flag provider.
 *
 * @template T - The type of the feature flag value.
 * @param {IFeatureFlagProvider} provider - The feature flag provider.
 * @param {string} key - The key of the feature flag.
 * @returns {UseFeatureResult<T>} - An object containing the feature flag value, a function to toggle the feature flag, and any error that occurred.
 */
export const useFeature = (provider, key) => {
    const feature$ = useMemo(() => provider.features$.pipe(findFeature(key)), [provider, key]);
    const { value: feature, error } = useObservableState(feature$ !== null && feature$ !== void 0 ? feature$ : EMPTY);
    const toggleFeature = useCallback((enable) => {
        var _a;
        const enabled = enable === undefined ? !((_a = provider.getFeature(key)) === null || _a === void 0 ? void 0 : _a.enabled) : enable;
        provider.toggleFeature({ key, enabled });
    }, [provider, key]);
    return { feature, toggleFeature, error };
};
export default useFeature;
//# sourceMappingURL=useFeature.js.map